@@ -2,15 +2,8 @@
 package PDL::Graphics::TriD::LinesFOOOLD;
 @ISA=qw/PDL::Graphics::TriD::Object/;
 
-BEGIN {
-   if ( $PDL::Config{USE_POGL} ) {
-      eval 'use OpenGL 0.58_007 qw(:all)';
-      eval 'use PDL::Graphics::OpenGL::Perl::OpenGL';
-   } else {
-      eval 'use PDL::Graphics::OpenGL';
-   }
-}
-
+use OpenGL qw(:all);
+use PDL::Graphics::OpenGL::Perl::OpenGL;
 use PDL::Lite;
 
 sub new {
